| AAcoor2NAcoor_df | R Documentation |
Like AAcoor2NAcoor, but takes a data.frame as input
AAcoor2NAcoor_df(dfdt, frmcol, AAc1col, AAc2col, outdf = T)
dfdt |
Input table to work on (data.frame or data.table) |
frmcol |
Column name of the field with the frame information. |
AAc1col |
Column name of the field with the start coordinate information. |
AAc2col |
Column name of the field with the end coordinate information. |
outdf |
Should output be a data.frame? |
Other BString_functions:
AAcoor2NAcoor_dFAST(),
AAcoor2NAcoor(),
DF2XString(),
Trim2Core2(),
XSDNARedunFilter(),
XString2DF(),
XString2KmerDT()
AAcoor2NAcoor_df
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.